@@ -55,7 +55,10 @@ class SVM:
         return np.sign(y_predict + self.b)
 
     def get_parameters(self, alphas):
-        sv = ((alphas > self.tol) * (alphas < self.C)).flatten()
+        if self.C is not None:
+            sv = ((alphas > self.tol) * (alphas < self.C)).flatten()
+        else:
+            sv = (alphas > self.tol).flatten()
         self.w = np.dot(self.X[sv].T, alphas[sv] * self.y[sv, np.newaxis])
         self.b = np.mean(
             self.y[sv, np.newaxis]
